logics Package
==============

:mod:`logics` Package
---------------------

.. automodule:: permission.logics
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`author` Module
--------------------

.. automodule:: permission.logics.author
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`base` Module
------------------

.. automodule:: permission.logics.base
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`collaborators` Module
---------------------------

.. automodule:: permission.logics.collaborators
    :members:
    :undoc-members:
    :show-inheritance:

